@@ -5,7 +5,8 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Install the C libxml2 library on your system
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.18_01'; # TRIAL VERSION
+$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
 
@@ -24,7 +25,7 @@ Alien::Libxml2 - Install the C libxml2 library on your system
 
 =head1 VERSION
 
-version 0.16
+version 0.18_01
 
 =head1 SYNOPSIS
 
@@ -36,7 +37,7 @@ In your Makefile.PL:
  WriteMakefile(
    Alien::Base::Wrapper->new('Alien::Libxml2')->mm_args2(
      # MakeMaker args
-     NAME => 'Kafka::Librd',
+     NAME => 'My::XS',
      ...
    ),
  );
@@ -112,7 +113,7 @@ Shlomi Fish (shlomif)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Graham Ollis.
+This software is copyright (c) 2013-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
